PRO alb 

;*************************************************************************
; Name: alb
;
; Purpose:
;   This rountine is the main driver to plot granule level surface albedos.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's albedo map, generated in
;    the albedo mapping routine, and produces albedo images for 6 spectral
;    bands.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the albedo map stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_alb.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names. 
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day')
time = GETENV('Time')
jday = fix(Day)

;*************************************************************************
; Define the file that contains the albedo information.
;*************************************************************************
stjday = Strcompress(string(jday),/REMOVE_ALL)
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filen = temp_HDF_path + 'GranAlbMap.'+year+'.'+day+'.'+time+'.hdf'
filenames = [filen]

;*************************************************************************
; Define the output path where the image is to be stored.
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 6
PlotSDS    = IntArr(numSDS)
PlotSDS[0] = 1 ; band 1 = 0.659 um 
PlotSDS[1] = 1 ; band 2 = 0.858 um
PlotSDS[2] = 1 ; band 3 = 1.24 um 
PlotSDS[3] = 1 ; band 4 = 1.64 um 
PlotSDS[4] = 1 ; band 5 = 2.13 um 
PlotSDS[5] = 1 ; band 6 = 3.74 um 

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
OutName    = StrArr(numSDS)
OutName[0] = '0.659'
OutName[1] = '0.858'
OutName[2] = '1.24'
OutName[3] = '1.64'
OutName[4] = '2.13'
OutName[5] = '3.74'


;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
TitleName    = StrArr(numSDS)
TitleName[0] = 'White Sky Albedo, MODIS band 1, 0.659 um'
TitleName[1] = 'White Sky Albedo, MODIS band 2, 0.858 um'
TitleName[2] = 'White Sky Albedo, MODIS band 5, 1.24 um'
TitleName[3] = 'White Sky Albedo, MODIS band 6, 1.64 um'
TitleName[4] = 'White Sky Albedo, MODIS band 7, 2.13 um'
TitleName[5] = 'White Sky Albedo, MODIS band 20, 3.74 um'


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
SDSLimits      = FltArr(numSDS,2)
SDSLimits[0,0] = 0.0 ;band 0, min
SDSLimits[0,1] = 0.5 ;band 0, max
SDSLimits[1,0] = 0.0 ;band 1, min
SDSLimits[1,1] = 0.5 ;band 1, max
SDSLimits[2,0] = 0.0 ;band 2, min
SDSLimits[2,1] = 0.5 ;band 2, max
SDSLimits[3,0] = 0.0 ;band 3, min
SDSLimits[3,1] = 0.5 ;band 3, max
SDSLimits[4,0] = 0.0 ;band 4, min
SDSLimits[4,1] = 0.5 ;band 5, max
SDSLimits[5,0] = 0.0 ;band 6, min
SDSLimits[5,1] = 0.5 ;band 6, max

;*************************************************************************
; Choose the number of text annotations to include on the color bar:
;*************************************************************************
Num_CB_Annotes    = IntArr(numSDS)
Num_CB_Annotes[0] = 5 ; band 0
Num_CB_Annotes[1] = 5 ; band 1
Num_CB_Annotes[2] = 5 ; band 2
Num_CB_Annotes[3] = 5 ; band 3
Num_CB_Annotes[4] = 5 ; band 4
Num_CB_Annotes[5] = 5 ; band 5


;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits      = StrArr(numSDS)
SDSunits[0]   = 'no units'
SDSunits[1]   = 'no units'
SDSunits[2]   = 'no units'
SDSunits[3]   = 'no units'
SDSunits[4]   = 'no units'
SDSunits[5]   = 'no units'


;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file.
;*************************************************************************
SDSName    = StrArr(numSDS)
SDSName[0] = 'Albedo_Map'
SDSName[1] = 'Albedo_Map'
SDSName[2] = 'Albedo_Map'
SDSName[3] = 'Albedo_Map'
SDSName[4] = 'Albedo_Map'
SDSName[5] = 'Albedo_Map'



;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;*************************************************************************
MDchoice    = IntArr(numSDS)
MDchoice[0] = 0
MDchoice[1] = 1
MDchoice[2] = 2
MDchoice[3] = 3
MDchoice[4] = 4
MDchoice[5] = 5





;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-1 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   OutFileName = output_dir+'Albedo.'+year+'.'+day+'.'+time+'.'+OutName[icnt]+'.tiff'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = TitleName[icnt]+'.  Time '+time+' Julian Day '+stjday+' '+year+'.'

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits=0
   ;   definition out and use the call without the limits included.
   ;*************************************************************************
   limits=0

   ;*************************************************************************
   ; Call the program:
   ;*************************************************************************
   ;Set the multidimension choice:
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (PlotSDS[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting Band ',OutName[icnt]
      SDS_limits = [SDSLimits[icnt,0],SDSLimits[icnt,1]]
      plot_alb, filenames, SDSName[icnt],       $
                OutFileName, SDS_limits,       $
                titlestring, multidim_choice,  $
                Num_CB_Annotes[icnt]
   ENDIF ELSE BEGIN
      print, 'Skipping ',OutName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor



END
