PRO anci 

;*************************************************************************
; Name: anci
;
; Purpose:
;   This rountine is the main driver to plot data from the MOD06OD Ancillary
;    HDF file, which is produced only when MOD06OD is run locally. Additionally,
;    this code will read lat/lon information from the supplied MOD03 file.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the ancillary file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_anci.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the files that contain the Ancillary data, including path.  
;*************************************************************************
;Define the path where the Ancillary HDF files reside:
AnciPath = GETENV('Input_Path')
 
;Define the Anci File Name:
Ancifilenames = StrArr(1)
Ancifilenames[0] = AnciPath+'MOD06OD_QC.A'+Year+Day+'.'+Time+'.txt'
print, 'Processing ',Ancifilenames


;*************************************************************************
; Define the Ancillary SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 7
PlotAnci    = IntArr(numSDS)
PlotAnci[0] = 1 ; Total Precipitable Water
PlotAnci[1] = 1 ; Cloud Top Height
PlotAnci[2] = 1 ; Cloud Top Temperature
PlotAnci[3] = 1 ; Temperature Profile
PlotAnci[4] = 1 ; Surface Temperature Over Land
PlotAnci[5] = 1 ; Surface Temperature Over Ocean
PlotAnci[6] = 1 ; Surface Albedo


;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
AnciOutName    = StrArr(numSDS)
AnciOutName[0] = 'Ttl_Prcip_Wtr'
AnciOutName[1] = 'Cld_Top_Hght'
AnciOutName[2] = 'Cld_Top_Temp'
AnciOutName[3] = 'Temp_Profile'
AnciOutName[4] = 'Surf_Temp_Lnd'
AnciOutName[5] = 'Surf_Temp_Ocn'
AnciOutName[6] = 'Albedo'


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
AnciSDSLimits      = FltArr(numSDS,2)
AnciSDSLimits[0,0] = 0.    ;Ttl_Precip_Wtr, min
AnciSDSLimits[0,1] = 7.5   ;Ttl_Precip_Wtr, max
AnciSDSLimits[1,0] = 300.  ;Cld_Top_Hght, min
AnciSDSLimits[1,1] = 1000. ;Cld_Top_Hght, max
AnciSDSLimits[2,0] = 200.  ;Cld_Top_Temp, min
AnciSDSLimits[2,1] = 300.  ;Cld_Top_Temp, max
AnciSDSLimits[3,0] = 200.  ;Temp_Profile, min
AnciSDSLimits[3,1] = 300.  ;Temp_Profile, max
AnciSDSLimits[4,0] = 275.  ;Surf_Temp_Land, min
AnciSDSLimits[4,1] = 310.  ;Surf_Temp_Land, max
AnciSDSLimits[5,0] = 275.  ;Surf_Temp_Ocn, min
AnciSDSLimits[5,1] = 310.  ;Surf_Temp_Ocn, max
AnciSDSLimits[6,0] = 0.    ;Albedo, min
AnciSDSLimits[6,1] = 0.5   ;Albedo, max


;*************************************************************************
; Choose the number text annotations to be included on the color bar:
;*************************************************************************
Num_CB_Annotes    = IntArr(numSDS)
Num_CB_Annotes[0] = 5 ;Ttl_Precip_Wtr 
Num_CB_Annotes[1] = 5 ;Cld_Top_Hght 
Num_CB_Annotes[2] = 5 ;Cld_Top_Temp
Num_CB_Annotes[3] = 5 ;Temp_Profile
Num_CB_Annotes[4] = 5 ;Surf_Temp_Land
Num_CB_Annotes[5] = 5 ;Surf_Temp_Ocn
Num_CB_Annotes[6] = 5 ;Albedo


;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits      = StrArr(numSDS)
SDSunits[0]   = 'g/cm^2'
SDSunits[1]   = 'hPa'
SDSunits[2]   = 'K'
SDSunits[3]   = 'K'
SDSunits[4]   = 'K'
SDSunits[5]   = 'K'
SDSunits[6]   = 'no units'


;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file.
;*************************************************************************
AnciSDSName    = StrArr(numSDS)
AnciSDSName[0] = 'Precipitable_Water_above_Cloud'
AnciSDSName[1] = 'Cloud_Top_Pressure'
AnciSDSName[2] = 'Cloud_Top_Temperature'
AnciSDSName[3] = 'Mean_Temperature_above_Cloud'
AnciSDSName[4] = 'Land_Surface_Temperature'
AnciSDSName[5] = 'Ocean_Surface_Temperature'
AnciSDSName[6] = 'Surface_Albedo'


;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;  Note the albedos will be looped over, so this can be set to 0 here.
;*************************************************************************
MDchoice    = IntArr(numSDS)
MDchoice[0] = 0
MDchoice[1] = 0
MDchoice[2] = 0
MDchoice[3] = 0
MDchoice[4] = 0 
MDchoice[5] = 0
MDchoice[6] = 0




;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.  This section
;   plots all but the albedoes
;*************************************************************************
for icnt = 0, numSDS-2 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   AnciOutFileName = output_dir+AnciOutName[icnt]+'.'+Year+'.'+Day+'.'+Time+'.tiff'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = AnciSDSname[icnt] + ', Year ' + Year + ', Day ' + Day + ', ' + Time

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits=0
   ;   definition out and use the call without the limits included.
   ;*************************************************************************
   limits=0


   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   ;Set the multi dimension choice
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   IF (PlotAnci[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',AnciSDSName[icnt]
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      plot_anci, Ancifilenames[0], AnciSDSName[icnt],  $
                   AnciOutFileName, SDS_limits,Num_CB_Annotes[icnt], $
                   titlestring, multidim_choice
   ENDIF ELSE BEGIN
      print, 'Skipping ',AnciSDSName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


;*************************************************************************
; Plot Surface Albedo,if desired.
;*************************************************************************
icnt = numSDS-1
IF (PlotAnci[icnt] eq 1) then begin

   band = strarr(6)
   band(0) = '0.659'
   band(1) = '0.865'
   band(2) = '1.240'
   band(3) = '1.640'
   band(4) = '2.130'
   band(5) = '3.750'

   ;*************************************************************************
   ;Loop over the bands:
   ;*************************************************************************
   for jcnt = 0, 5 do begin

      ;**********************************************************************
      ; Define the name of the output image file, including path:
      ;**********************************************************************
      strjcnt = strcompress(string(jcnt+1),/REMOVE_ALL)
      AnciOutFileName = output_dir + AnciOutName[icnt] + '_' + band[jcnt] + $
                        '.' + Year + '.' + Day + '.' + Time + '.tiff'

      ;**********************************************************************
      ; Add a title to the plot if desired. Ex. titlestring ='Title'
      ;**********************************************************************
      ;titlestring = 'Year 2000, Day 110, combined granules 0855 and 0900'
      titlestring = AnciSDSName[icnt] + ', ' + band[jcnt] +' micron, ' + strjcnt + ', Year ' + Year + $
                    ', Day ' + Day + ', ' + Time

      ;**********************************************************************
      ;Call the program:
      ;**********************************************************************
      ;Set multidim_choice to the jcnt:
      multidim_choice = jcnt
      ;Call the plotting code:
      print, 'Plotting ',AnciSDSName[icnt],' ',band[jcnt]
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      plot_anci, Ancifilenames[0], AnciSDSName[icnt],  $
                   AnciOutFileName, SDS_limits, Num_CB_Annotes[icnt],$
                   titlestring, multidim_choice

   ;*************************************************************************
   ;End the looping:
   ;*************************************************************************
   endfor

;End the if loop:
endif



END
