pro plot_l1b,filename,outputname,titlestring

;*************************************************************************
; Name: plot_l1b
;
; Purpose:
;   This routine is the main code for reading/altering data and creating
;     the image to be generated, as per input specifications.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   filename:           Path and HDF file name which contains the data set to plot.
;   outputname:         Path and file name of the image to be generated.
;   titlesting:         String containing the title to be added to the top of the plot.
;
; Outputs:
;  None. 
;
; Required Programs:
;  Read_L1B_sds.pro
;  applycolorcurve.pro
;  prettymodis.amp 
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;Open the L1B file:
fileId = HDF_SD_START(filename, /READ)

  ;Read in the 250m, band 1 data:
  sds_name = 'EV_250_Aggr1km_RefSB'
  read_l1b_sds,data_250m,range,fileId,sds_name,fail,/scaleNo,/offsetNo

  ;Read in the scale:
  index = HDF_SD_NAMETOINDEX(fileId, sds_name)
  sdsid = HDF_SD_SELECT(fileId, index)
  scale_sds_name= 'reflectance_scales'
  scaleId = HDF_SD_ATTRFIND(sdsid,scale_sds_name)
  HDF_SD_ATTRINFO, sdsid, scaleId, DATA=scale_factor
  HDF_SD_ENDACCESS, sdsid

  ;Scale band 1 data:
  band1_data = data_250m[*,*,0] * scale_factor[0]
  data_250m = 0


  ;Read in the 500m, band 3 and 4 data:
  sds_name = 'EV_500_Aggr1km_RefSB'
  read_l1b_sds,data_500m,range,fileId,sds_name,fail,/scaleNo,/offsetNo

  ;Read in the scale:
  index = HDF_SD_NAMETOINDEX(fileId, sds_name)
  sdsid = HDF_SD_SELECT(fileId, index)
  scale_sds_name= 'reflectance_scales'
  scaleId = HDF_SD_ATTRFIND(sdsid,scale_sds_name)
  HDF_SD_ATTRINFO, sdsid, scaleId, DATA=scale_factor
  HDF_SD_ENDACCESS, sdsid

  ;Scale band 3 data:
  band3_data = data_500m[*,*,0] * scale_factor[0]

  ;Scale band 4 data:
  band4_data = data_500m[*,*,1] * scale_factor[1]
  data_500m = 0

HDF_SD_END, fileId



;Define various sizes used for createing the image.
;Obtain the size of the arrays:
dimsizes = size(band1_data)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)

;Define the extra space for the colorbar and margins:
margins       = 10
title_ysize   = 100

;Redefine the x and y sizes, to include margin and room for the title:
xsize = data_xsize + margins * 2
ysize = data_ysize + margins * 2 + title_ysize



;Store the bands in one array:
bands = fltarr(data_xsize,data_ysize,3)
bands(*,*,0) = band1_data(*,*)
bands(*,*,1) = band4_data(*,*)
bands(*,*,2) = band3_data(*,*)

;Set anything > 1 to 1, and < 0 to 0:


;Bytescale the data, between 0-255, 0.0-1.0:
bands = bytscl( bands, max = 1.0, min = 0.0 )

;Apply the color curve:
curvename = 'prettymodis.amp'
applycolorcurve, curvename, bands



;Create the z buffer:
Set_plot, 'z',/COPY
Device, Set_Resolution=[xsize,ysize]
!p.font=3
Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font


;"paint" the z buffer white:
temp_arr = bytarr(xsize,ysize)
temp_arr(*,*) = 255
tv, temp_arr


;Center the title string at the top of the page:
xyouts, (float(data_xsize)/2.0+float(margins))/float(xsize), $
        float(ysize-margins-title_ysize/2)/float(ysize),     $
        titlestring, /NORMAL, alignment = 0.5,               $
        charsize = 0.7, charthick = 4, color = 0

;Read the z buffer into image array:
image = tvrd()

;Close the z buffer:
device, /close

;Reverse the colorbar image for proper storage:
image = reverse(image,2)


;Create the 3D image
image3D = bytarr(3,xsize,ysize)
image3D(0,*,*) = image(*,*)
image3D(1,*,*) = image(*,*)
image3D(2,*,*) = image(*,*)

;Store the data in the output array
for icnt = 0, data_xsize - 1 do begin
    for jcnt = 0, data_ysize -1 do begin
        image3D(0,icnt+margins,jcnt+margins+title_ysize) = bands(icnt,jcnt,0)
        image3D(1,icnt+margins,jcnt+margins+title_ysize) = bands(icnt,jcnt,1)
        image3D(2,icnt+margins,jcnt+margins+title_ysize) = bands(icnt,jcnt,2)
    endfor
endfor



;Write to the tiff file:
write_tiff,outputname,image3D,1





end
