pro plot_phase, mod06filename,sds_name,outputname,sds_limits,         $
                titlestring,multidim_choice,Num_CB_Annotes,diff_flag,  $
                water_flag,delta_zero,log_scale

;*************************************************************************
; Name: plot_l2
;
; Purpose:
;   This routine is the main code for reading/altering data and creating
;     the image to be generated, as per input specifications.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   mod06filename:      Path and HDF file name which contains the data set to plot.
;   sds_name:           Name of the data set to be plotted, as given in the HDF file.
;   outputname:         Path and file name of the image to be generated.
;   sds_limits:         Upper and lower data limits, used for applying color schemes.
;   Num_CB_Annotes:     The number of text annotations to be used on the colorbar.
;   titlesting:         String containing the title to be added to the top of the plot.
;   multidim_choice:    If the array is mulit-banded, this variable specifies which band is used.
;   diff_flag:		If this is to be a difference plot or not.
;   water_flag:         The type of water that is to be used, water, undetermined, water+undetermined.
;   delta_zero:         The delta around zero which is to be colored grey, only for diff plots.
;   log_scale:          If we are to use the log scale.
;
; Outputs:
;  None. 
;
; Required Programs:
;  colorscale_phase.pro
;  Read_Product_sds.pro
;  colorbar_log.pro
;  l2qa_bitextracter.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;Call to set up the color scale:
colorscale_phase, r, g, b


;Read in the image data:
fileId = HDF_SD_START(mod06filename, /READ)
  Read_product_sds,data,range,fillvalue,fileId,sds_name,fail
HDF_SD_END, fileId

;get dimensions of sds data.  If there is more than one then use
;the multi-dimensional_choice argument to extract it.
temp_sizeinfo=size(data)
if (temp_sizeinfo(0) eq 3) then begin
  if temp_sizeinfo(3) gt temp_sizeinfo(1) then begin
    newdata=fltarr(temp_sizeinfo(2),temp_sizeinfo(3))
    newdata(*,*) = data(multidim_choice,*,*)
    data=newdata
    newdata = 0
  endif
  if temp_sizeinfo(1) gt temp_sizeinfo(3) then begin
    newdata=fltarr(temp_sizeinfo[1],temp_sizeinfo[2])
    newdata[*,*] = data[*,*,multidim_choice]
    data=newdata
    newdata = 0
  endif
endif

;If this is a difference field, check to see if difference field is to be plotted,
;  or if we should add off the 2.1:
if (sds_name eq 'Effective_Radius_Difference') then begin
  ;Check to see if the difference field is to be plotted.  If not, add off the 2.1:
  if (diff_flag eq 0) then begin

    ;We are plotting the effective radius, so read in the 2.1, and
    ; add it to the difference.
    fileId = HDF_SD_START(mod06filename, /READ)
      Read_product_sds,EPR_21_data,range2,fillvalue2,fileId,'Effective_Particle_Radius',fail2 
    HDF_SD_END, fileId

    ;Reset the fill values to the fill value:
    index = where((data lt -900.0),fill_cnt)
    data[*,*] = data[*,*] + EPR_21_data[*,*]
    if fill_cnt gt 0 then data[index] = fillvalue

  endif else begin

    ;We are plotting the differences, and would like any value +- delta_zero 
    ; to be gray.

    ;First work on the Ice color scale (ranges between 0-126).
    ;Define the upper and lower limits to set to white 
    top_lim = delta_zero(1)
    bot_lim = delta_zero(0)
    ;Figure out the index of the upper and lower points to
    ; be shaded white:
    tot_cb_levels = 127.
    delta_cb = (sds_limits(0,1)-sds_limits(0,0)) / tot_cb_levels
    tot_gray_lvls = fix( abs(top_lim-bot_lim) / delta_cb )

    bot_lvl = fix( abs(bot_lim-sds_limits(0,0))  /delta_cb )
    top_lvl = bot_lvl + tot_gray_lvls 
 
    ;Set those levels to a light gray:
    r(bot_lvl:top_lvl) = 150B
    g(bot_lvl:top_lvl) = 150B
    b(bot_lvl:top_lvl) = 150B


    ;Next work on the Water color scale (ranges between 127-253).
    ;Define the upper and lower limits to set to white
    top_lim = delta_zero(1)
    bot_lim = delta_zero(0)
    ;Figure out the index of the upper and lower points to
    ; be shaded white:
    tot_cb_levels = 127.
    delta_cb = (sds_limits(0,1)-sds_limits(0,0)) / tot_cb_levels
    tot_gray_lvls = fix( abs(top_lim-bot_lim) / delta_cb )

    bot_lvl = fix( abs(bot_lim-sds_limits(0,0))  /delta_cb ) + 127
    top_lvl = bot_lvl + tot_gray_lvls
 
    ;Set those levels to a light gray:
    r(bot_lvl:top_lvl) = 75B
    g(bot_lvl:top_lvl) = 75B
    b(bot_lvl:top_lvl) = 75B


  endelse
endif


;Ensure that the data is float:
data      = float(data)
fillvalue = float(fillvalue)


;Read in the L2 QA and extract the cloud phase:
Cloud_Phase = l2qa_bitextracter(mod06filename)


;Obtain the size of the data arrays:
dimsizes = size(data)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)


;Break the combined data into phases, store in an array,
;  where the indices mean:
;  Phase_data[0,*,*] = Ice
;  Phase_data[1,*,*] = Water, Undetermined, Water+Undetermined
Phase_data    = fltarr(2,data_xsize,data_ysize)

;Ice:
dummy_data = data
indices = where((Cloud_Phase ne 3),ind_cnt)
if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
Phase_data[0,*,*] = dummy_data[*,*]

;Create the water/undetermined/water+undetermined array
case water_flag of
  0 :  begin
        ;Water:
        dummy_data = data
        indices = where((Cloud_Phase ne 2),ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
        Phase_data[1,*,*] = dummy_data[*,*]
       end
  1 :  begin
        ;Undetermined:
        dummy_data = data
        indices = where((Cloud_Phase ne 4),ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
        Phase_data[1,*,*] = dummy_data[*,*]
       end
  2 :  begin
        ;Water + Undetermined:
        dummy_data = data
        dummy_data[*,*] = fillvalue
        indices = where( (Cloud_Phase eq 2) or (Cloud_Phase eq 4), ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = data(indices)
        Phase_data[1,*,*] = dummy_data[*,*]
       end
endcase


;
;Byte scale the data in two stages, 
;  where ice is assigned  0  - 126 and
;      water is assigned 127 - 253.
; Values beyond the max and min are set to the upper limit.
;

;Byte scale the ice:
dummy_data  = fltarr(data_xsize,data_ysize)
dummy_data[*,*] = Phase_data[0,*,*]

if (log_scale eq 1) then begin
  ;This should be plotted as log.
  ;store the data in a temp array:
  log_data        = dummy_data

  ;Set the values less than 1 to 1, and convert to log space:
  lt_pixels = where((log_data lt 1.0),ltcnt)
  if ltcnt gt 0 then log_data(lt_pixels) = 1.0
  log_data   = alog10(log_data)
  log_sds_limits = alog10(sds_limits)

  ;Byte scale the data between 0 - 126:
  ice_image = bytscl( log_data,                  $
                      min = log_sds_limits(0,0), $
                      max = log_sds_limits(0,1), $
                      top = 126                  ) 

  ;Set the log_data array to zero:
  log_data = 0

endif else begin
  ;This in non-log, so just byte scale as usual:
  ;Byte scale the data between 0 - 126:
  ice_image = bytscl( dummy_data,            $
                      min = sds_limits(0,0), $
                      max = sds_limits(0,1), $
                      top = 126              ) 
endelse

;Set the fill values to 255, or black:
fill_pixels = where((dummy_data eq fillvalue),fillcnt)
if fillcnt gt 0 then ice_image(fill_pixels) = 255

;Set data array to 0:
dummy_data = 0


;Byte scale the water:
dummy_data  = fltarr(data_xsize,data_ysize)
dummy_data[*,*] = Phase_data[1,*,*]

if (log_scale eq 1) then begin
  ;This should be plotted as log.
  ;store the data in a temp array:
  log_data        = dummy_data

  ;Set the values less than 1 to 1, and convert to log space:
  lt_pixels = where((log_data lt 1.0),ltcnt)
  if ltcnt gt 0 then log_data(lt_pixels) = 1.0
  log_data   = alog10(log_data)
  log_sds_limits = alog10(sds_limits)

  ;Byte scale the data between 127-253:
  water_image = bytscl( log_data,                  $
                        min = log_sds_limits(1,0), $
                        max = log_sds_limits(1,1), $
                        top = 126                  ) + 127B

  ;Set the log_data array to zero:
  log_data = 0

endif else begin
  ;This in non-log, so just byte scale as usual:
  ;Byte scale the data between 127-253:
  water_image = bytscl( dummy_data,             $
                        min = sds_limits(1,0),  $
                        max = sds_limits(1,1),  $
                        top = 126               ) + 127B 
endelse

;Set the fill values to 255, or black:
fill_pixels = where((dummy_data eq fillvalue),fillcnt)
if fillcnt gt 0 then water_image(fill_pixels) = 255

;Set data array to 0:
dummy_data = 0


;Combine the two images into a single image:
;Start with the ice image:
comb_image = ice_image

;Where the water image is not fill, add to the comb_image:
indices = where((water_image ne 255),ind_cnt)
if (ind_cnt gt 0) then comb_image(indices) = water_image(indices)




;Define various sizes used for createing the image.
;Obtain the size of the arrays:
dimsizes = size(comb_image)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)

;Define the extra space for the colorbars:
xsize_factor  = 0.25
cb_xsize      = fix(xsize_factor * data_xsize)
ysize_factor  = 0.8 / 2.0 ; Since 2 colorbars
cb_ysize      = fix(ysize_factor * data_ysize)
;pixels above/below the center point for the cb's:
pix_bey_centr = 30

;Define the margin sizes:
margins       = 10
gap_cb_xsize  = 15
title_ysize   = 100

;Redefine the x and y sizes, to include margin and room for the colorbar:
xsize = data_xsize  + gap_cb_xsize + cb_xsize + margins * 2
ysize = data_ysize + margins * 2 + title_ysize




;Create the z buffer:
Set_plot, 'z',/COPY
Device, Set_Resolution=[xsize,ysize]
!p.font=3
Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font


;"paint" the z buffer white:
temp_arr = bytarr(xsize,ysize)
temp_arr(*,*) = 254
tv, temp_arr


;
;Plot the colorbars to the z buffer:
;
;Define the position (in relative terms) of the colorbar:
;The colorbar begins to the right of the data, with a gap:
xbeg    = float(data_xsize + gap_cb_xsize + margins) / float(xsize)
xend    = xbeg + 0.04

;Define the central y point:
y_center = float(ysize) / 2.0

;The ice color bar:
;The colorbar is to be below the central y axis, define start/stop points:
ybeg    = float(y_center-pix_bey_centr-cb_ysize) / float(ysize)
yend    = ybeg + float(cb_ysize) / float(ysize)

;Call to plot the colorbar:
colorbar_log, /vertical, /right, position=[xbeg, ybeg, xend, yend],  $
              divisions=Num_CB_Annotes, minrange = sds_limits(0,0),  $
              maxrange = sds_limits(0,1), font=1, format = '(F6.2)', $
              BOTTOM = 0, NCOLORS=127,title = 'Ice',log_scale=log_scale


;The water color bar:
;The colorbar is to be above the central y axis, define start/stop points:
ybeg    = float(y_center+pix_bey_centr) / float(ysize)
yend    = ybeg + float(cb_ysize) / float(ysize)

;Call to plot the colorbar:
colorbar_log, /vertical, /right, position=[xbeg, ybeg, xend, yend],  $
              divisions=Num_CB_Annotes, minrange=sds_limits(1,0),    $ 
              maxrange=sds_limits(1,1), font=1, format = '(F6.2)',   $
              BOTTOM = 127, NCOLORS=127,Title = 'Water',log_scale=log_scale



;Center the title string at the top of the page:
xyouts, (float(data_xsize)/2.0+float(margins))/float(xsize), $
        float(ysize-margins-title_ysize/2)/float(ysize),     $
        titlestring, /NORMAL, alignment = 0.5,               $
        charsize = 0.7, charthick = 4

;Read the z buffer into image array:
image = tvrd()

;Close the z buffer:
device, /close

;Reverse the colorbar image for proper storage:
image = reverse(image,2)



;Store the data in the output array
for icnt = 0, data_xsize - 1 do begin
    for jcnt = 0, data_ysize -1 do begin
        image(icnt+margins,jcnt+margins+title_ysize) = comb_image(icnt,jcnt)
    endfor
endfor




;Write to the tiff file:
write_tiff,outputname,image,1,red=r,green=g,blue=b





end
