pro plot_re_phase,mod06filename,outputname,sds_limits,   $
                  phase_title,titlestring,Num_CB_Annotes

;*************************************************************************
; Name: plot_re_phase
;
; Purpose:
;   This routine is the main code for reading/altering data and creating
;     the image to be generated, as per input specifications.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   mod06filename:      Path and HDF file name which contains the data set to plot.
;   outputname:         Path and file name of the image to be generated.
;   sds_limits:         Upper and lower data limits, used for applying color schemes.
;   Num_CB_Annotes:     The number of text annotations to be used on the colorbar.
;   phase_title:        Individual titles for the three plots.
;   titlesting:         String containing the title to be added to the top of the plot.
;
; Outputs:
;  None. 
;
; Required Programs:
;  colorscale.pro
;  Read_Product_sds.pro
;  colorbar.pro
;  l2qa_bitextracter.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;Read in the Effective particle Radius:
sds_name = 'Effective_Particle_Radius'
fileId = HDF_SD_START(mod06filename, /READ)
  Read_product_sds,EPR_data,range,fillvalue,fileId,sds_name,fail
HDF_SD_END, fileId


;Ensure that the data is float:
EPR_data  = float(EPR_data)
fillvalue = float(fillvalue)


;Read in the L2 QA and extract the cloud phase:
Cloud_Phase = l2qa_bitextracter(mod06filename)


;Obtain the size of the data arrays:
dimsizes = size(EPR_data)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)


;Separate the phases and store in separate arrays:
EPR_Phase_data    = fltarr(3,data_xsize,data_ysize)

dummy_data = EPR_data
dummy_data(where(Cloud_Phase ne 3)) = fillvalue
EPR_Phase_data[0,*,*] = dummy_data[*,*]

dummy_data = EPR_data
dummy_data(where(Cloud_Phase ne 2)) = fillvalue
EPR_Phase_data[1,*,*] = dummy_data[*,*]

dummy_data = EPR_data
dummy_data(where(Cloud_Phase ne 4)) = fillvalue
EPR_Phase_data[2,*,*] = dummy_data[*,*]




;Define the extra space for the colorbar and margins:
xsize_factor  = 0.10
cb_xsize      = fix(xsize_factor * data_xsize)
ysize_factor  = 0.5
cb_ysize      = fix(ysize_factor * data_ysize)
margins       = 10
gap_cb_xsize  = 15
title_ysize   = 250

;Redefine the x and y sizes, to include margin and room for the colorbar:
xsize = data_xsize  + gap_cb_xsize + cb_xsize + margins * 2
ysize = data_ysize + margins * 2 + title_ysize


;Create the array which stores the phase and final images:
;Array for storing the individual phase images:
phase_images = bytarr(3,xsize,ysize)
;Array that contains the final image:
final_image  = bytarr(xsize*3,ysize)

;Call to set up the color scale:
colorscale,r,g,b

;
;Loop over the 3 phases, producing the images for each,
; storing the images in data arrays:
;
for phase_cnt = 0, 2 do begin

   print,'Processing ',phase_title[phase_cnt],' Phase.'

   ;Byte scale the data for output:
   sds_image = 0
   dummy_data = fltarr(data_xsize,data_ysize)
   dummy_data[*,*] = EPR_Phase_data[phase_cnt,*,*]
   sds_image = bytscl( dummy_data,                     $
                       min = sds_limits(phase_cnt,0),  $
                       max = sds_limits(phase_cnt,1),  $
                       top = !d.table_size - 3    ) 

   ;Set the fill values to 255, or black:
   fill_pixels = where((dummy_data eq fillvalue),fillcnt)
   if fillcnt gt 0 then sds_image(fill_pixels) = 255


   ;Create the z buffer:
   Set_plot, 'z',/COPY
   Device, Set_Resolution=[xsize,ysize]
   !p.font=3
   Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font


   ;"paint" the z buffer white:
   temp_arr      = bytarr(xsize,ysize)
   temp_arr(*,*) = 254
   tv, temp_arr
   temp_arr=0


   ;Plot the colorbar to the z buffer:

   ;Define the position (in relative terms) of the colorbar:
   ;The colorbar begins to the right of the data, with a gap:
   xbeg    = float(data_xsize + gap_cb_xsize + margins) / float(xsize)
   xend    = xbeg + 0.04
   ;The colorbar is to be centered on the y axis, define start/stop points:
   ybeg    = float(ysize/2 - title_ysize - cb_ysize/2) / float(ysize)
   yend    = ybeg + float(cb_ysize) / float(ysize)

   ;Call to plot the colorbar:
   colorbar, /vertical, /right, position=[xbeg, ybeg, xend, yend],  $
             divisions=Num_CB_Annotes[phase_cnt], range=sds_limits(phase_cnt,*),  $
             font=1, format = '(F6.1)', NCOLORS=254

   ;Center the title string at the top of the page:
   xyouts, (float(data_xsize)/2.0+float(margins))/float(xsize), $
;           float(ysize-margins-title_ysize/2)/float(ysize),     $
           float(ysize-margins-title_ysize+40)/float(ysize),    $
           phase_title[phase_cnt], /NORMAL, alignment = 0.5,    $
           charsize = 1.0, charthick = 4

   ;Read the z buffer into image array:
   image = tvrd()

   ;Close the z buffer:
   device, /close

   ;Reverse the colorbar image for proper storage:
   image = reverse(image,2)

   ;Store the data in the output array
   for icnt = 0, data_xsize - 1 do begin
       for jcnt = 0, data_ysize -1 do begin
           image(icnt+margins,jcnt+margins+title_ysize) = sds_image(icnt,jcnt)
       endfor
   endfor

   ;Store the image in the phase image array:
   phase_images[phase_cnt,*,*] = image[*,*]


;End the looping:
endfor

;
;Combine the three images into a final image:
;
print, 'Creating the final image...'


;Create the z buffer:
Set_plot, 'z',/COPY
Device, Set_Resolution=[3*xsize,ysize]
!p.font=3
Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font

;First set the final image to white:
final_image[*,*] = 254
temp_image = final_image
tv, temp_image

;Add the overall title to this plot"
;Center the title string at the top of the page:
xyouts, 0.50,                                  $
        float(ysize-margins-75)/float(ysize),  $
        titlestring, /NORMAL, alignment = 0.5, $
        charsize = 1.4, charthick = 6

;Read the z buffer into the temp_image array:
temp_image = tvrd()

;Close the z buffer:
device, /close

;Reverse the image for proper storage:
temp_image = reverse(temp_image,2)

;Loop over each phase and store in the final array:
for phase_cnt = 0, 2 do begin
  for icnt = 0, xsize -1 do begin
     for jcnt = 0, ysize -1 do begin
        xindex = icnt + phase_cnt * xsize
        final_image[xindex,jcnt] = phase_images[phase_cnt,icnt,jcnt]
     endfor
  endfor
endfor

;Add the title to the final image:
for icnt = 0, (3*xsize)-1 do begin
    for jcnt = 0, 100 do begin
        final_image[icnt,jcnt] = temp_image[icnt,jcnt]
    endfor
endfor


;Write to the tiff file:
write_tiff,outputname,final_image,1,red=r,green=g,blue=b





end
